{
    "$graph": [
        {
            "class": "Workflow",
            "id": "#main",
            "requirements": [
                {
                    "class": "ScatterFeatureRequirement"
                },
                {
                    "class": "MultipleInputFeatureRequirement"
                },
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".64.amb",
                        ".64.ann",
                        ".64.bwt",
                        ".64.pac",
                        ".64.sa",
                        ".64.alt",
                        "^.dict"
                    ],
                    "id": "#main/indexed_reference_fasta"
                },
                {
                    "type": "File",
                    "id": "#main/input_se_reads"
                },
                {
                    "type": "string",
                    "id": "#main/input_se_rgs"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "id": "#main/min_alignment_score"
                }
            ],
            "steps": [
                {
                    "run": "#bwa_mem_naive.cwl",
                    "in": [
                        {
                            "source": "#main/min_alignment_score",
                            "id": "#main/bwa_mem_split_se_reads/min_alignment_score"
                        },
                        {
                            "source": "#main/zcat_split_reads/output",
                            "id": "#main/bwa_mem_split_se_reads/reads"
                        },
                        {
                            "source": "#main/indexed_reference_fasta",
                            "id": "#main/bwa_mem_split_se_reads/ref"
                        },
                        {
                            "source": "#main/input_se_rgs",
                            "id": "#main/bwa_mem_split_se_reads/rg"
                        }
                    ],
                    "scatter": "#main/bwa_mem_split_se_reads/reads",
                    "out": [
                        "#main/bwa_mem_split_se_reads/output"
                    ],
                    "id": "#main/bwa_mem_split_se_reads"
                },
                {
                    "hints": [
                        {
                            "class": "https://sevenbridges.comAWSInstanceType",
                            "value": "c5.9xlarge"
                        }
                    ],
                    "run": "#fastq_chomp.cwl",
                    "in": [
                        {
                            "source": "#main/input_se_reads",
                            "id": "#main/zcat_split_reads/input_fastq"
                        }
                    ],
                    "out": [
                        "#main/zcat_split_reads/output"
                    ],
                    "id": "#main/zcat_split_reads"
                }
            ],
            "hints": [
                {
                    "class": "https://sevenbridges.commaxNumberOfParallelInstances",
                    "value": 4
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputSource": "#main/bwa_mem_split_se_reads/output",
                    "id": "#main/unsorted_bams"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#bwa_mem_naive.cwl",
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 50000,
                    "coresMin": 36
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "zhangb1/bwa-kf-bundle:0.1.17"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "baseCommand": [
                "/bin/bash",
                "-c"
            ],
            "doc": "The program can handle the following classes of inputs:\n - single end reads (only reads File and rg string provided)\n - reads with mates (reads File, mates File, and rg string provided)\n - interleaved reads (reads File provided, rg string provided, and interleaved set to true)\nThis tool runs the following programs:\n - bwa mem | samblaster | sambamba view | sambamba sort",
            "arguments": [
                {
                    "position": 0,
                    "shellQuote": false,
                    "valueFrom": "set -eo pipefail\nbwa mem -K 100000000 ${if (inputs.interleaved) {return '-p';} else {return \"\"}} -v 3 -t 36 ${if (inputs.min_alignment_score == null) { return '';} else {return '-T ' + inputs.min_alignment_score;}} -Y $(inputs.ref.path) -R"
                },
                {
                    "position": 2,
                    "shellQuote": false,
                    "valueFrom": "${return inputs.reads.path} ${if (inputs.mates != null) {return inputs.mates.path} else {return \"\"}} | /opt/samblaster/samblaster -i /dev/stdin -o /dev/stdout | /opt/sambamba_0.6.3/sambamba_v0.6.3 view -t 36 -f bam -l 0 -S /dev/stdin | /opt/sambamba_0.6.3/sambamba_v0.6.3 sort -t 36 --natural-sort -m 15GiB --tmpdir ./ -o ${if (inputs.reads != null) {return inputs.reads.nameroot} else {return \"\"}}.unsorted.bam -l 5 /dev/stdin"
                }
            ],
            "inputs": [
                {
                    "type": "boolean",
                    "default": false,
                    "doc": "The reads input is interleaved",
                    "id": "#bwa_mem_naive.cwl/bwa_mem_naive/interleaved"
                },
                {
                    "type": [
                        "null",
                        "File"
                    ],
                    "doc": "Mates file for the reads",
                    "id": "#bwa_mem_naive.cwl/bwa_mem_naive/mates"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "doc": "Don't output alignment with score lower than INT. This option only affects output.",
                    "id": "#bwa_mem_naive.cwl/bwa_mem_naive/min_alignment_score"
                },
                {
                    "type": "File",
                    "doc": "Primary reads file",
                    "id": "#bwa_mem_naive.cwl/bwa_mem_naive/reads"
                },
                {
                    "type": "File",
                    "secondaryFiles": [
                        ".64.amb",
                        ".64.ann",
                        ".64.bwt",
                        ".64.pac",
                        ".64.sa",
                        "^.dict",
                        ".fai"
                    ],
                    "doc": "Reference fasta file with associated indexes",
                    "id": "#bwa_mem_naive.cwl/bwa_mem_naive/ref"
                },
                {
                    "type": "string",
                    "doc": "Formatted RG header to use in the resulting BAM, check BWA for formatting guidelines (e.g. escaped tabs '\t')",
                    "inputBinding": {
                        "position": 1
                    },
                    "id": "#bwa_mem_naive.cwl/bwa_mem_naive/rg"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "*.bam"
                    },
                    "id": "#bwa_mem_naive.cwl/bwa_mem_naive/output"
                }
            ]
        },
        {
            "class": "CommandLineTool",
            "id": "#fastq_chomp.cwl",
            "doc": "This tool will chomp any fastq larger than the max size (10 gb by default) into 320000000 line chunks (80M reads). \nPrograms used in this tool:\n  - zcat | split\n  - ls | mv",
            "requirements": [
                {
                    "class": "ShellCommandRequirement"
                },
                {
                    "class": "ResourceRequirement",
                    "ramMin": 8000,
                    "coresMin": 4
                },
                {
                    "class": "DockerRequirement",
                    "dockerPull": "kfdrc/bwa-bundle:dev"
                },
                {
                    "class": "InlineJavascriptRequirement"
                }
            ],
            "baseCommand": [
                "/bin/bash",
                "-c"
            ],
            "arguments": [
                {
                    "position": 0,
                    "shellQuote": false,
                    "valueFrom": "set -eo pipefail\n\nif [ $(inputs.input_fastq.size) -gt $(inputs.max_size) ]; then\n  zcat $(inputs.input_fastq.path) | split -dl 320000000 - reads-\n  ls reads-* | xargs -i mv {} {}.fq\nelse\n  echo \"FASTQ not large enough to split.\"\nfi"
                }
            ],
            "inputs": [
                {
                    "type": "File",
                    "doc": "Input fastq file",
                    "id": "#fastq_chomp.cwl/fastq_chomp/input_fastq"
                },
                {
                    "type": "long",
                    "default": 10000000000,
                    "doc": "The maximum size (in bytes) that an input bam can be before the FASTQ is split",
                    "id": "#fastq_chomp.cwl/fastq_chomp/max_size"
                }
            ],
            "outputs": [
                {
                    "type": {
                        "type": "array",
                        "items": "File"
                    },
                    "outputBinding": {
                        "glob": "*.fq",
                        "outputEval": "${\n  if (self.length == 0) return [inputs.input_fastq]\n  else return self\n}"
                    },
                    "id": "#fastq_chomp.cwl/fastq_chomp/output"
                }
            ]
        }
    ],
    "cwlVersion": "v1.0",
    "$namespaces": {
        "sbg": "https://sevenbridges.com"
    }
}
